@@ -47,7 +47,7 @@
 
 namespace KisLayerUtils {
 
-    void fetchSelectionMasks(QList<KisNodeSP> mergedNodes, QVector<KisSelectionMaskSP> &selectionMasks)
+    void fetchSelectionMasks(KisNodeList mergedNodes, QVector<KisSelectionMaskSP> &selectionMasks)
     {
         foreach (KisNodeSP node, mergedNodes) {
             KisLayerSP layer = dynamic_cast<KisLayer*>(node.data());
@@ -77,7 +77,7 @@ namespace KisLayerUtils {
         SwitchFrameCommand::SharedStorageSP storage;
         QSet<int> frames;
 
-        virtual QList<KisNodeSP> allSrcNodes() = 0;
+        virtual KisNodeList allSrcNodes() = 0;
         virtual KisLayerSP dstLayer() { return 0; }
     };
 
@@ -97,8 +97,8 @@ namespace KisLayerUtils {
         KisLayerSP prevLayer;
         KisLayerSP currLayer;
 
-        QList<KisNodeSP> allSrcNodes() {
-            QList<KisNodeSP> mergedNodes;
+        KisNodeList allSrcNodes() {
+            KisNodeList mergedNodes;
             mergedNodes << currLayer;
             mergedNodes << prevLayer;
             return mergedNodes;
@@ -111,7 +111,7 @@ namespace KisLayerUtils {
 
     struct MergeMultipleInfo : public MergeDownInfoBase {
         MergeMultipleInfo(KisImageSP _image,
-                          QList<KisNodeSP> _mergedNodes)
+                          KisNodeList _mergedNodes)
             : MergeDownInfoBase(_image),
               mergedNodes(_mergedNodes)
         {
@@ -120,9 +120,9 @@ namespace KisLayerUtils {
             }
         }
 
-        QList<KisNodeSP> mergedNodes;
+        KisNodeList mergedNodes;
 
-        QList<KisNodeSP> allSrcNodes() {
+        KisNodeList allSrcNodes() {
             return mergedNodes;
         }
     };
@@ -351,11 +351,11 @@ namespace KisLayerUtils {
      * That's why we need to care about the order of the nodes removal:
      * the clone --- first, the source --- last.
      */
-    void RemoveNodeHelper::safeRemoveMultipleNodes(QList<KisNodeSP> nodes, KisImageSP image) {
+    void RemoveNodeHelper::safeRemoveMultipleNodes(KisNodeList nodes, KisImageSP image) {
         const bool lastLayer = scanForLastLayer(image, nodes);
 
         while (!nodes.isEmpty()) {
-            QList<KisNodeSP>::iterator it = nodes.begin();
+            KisNodeList::iterator it = nodes.begin();
 
             while (it != nodes.end()) {
                 if (!checkIsSourceForClone(*it, nodes)) {
@@ -377,7 +377,7 @@ namespace KisLayerUtils {
         }
     }
 
-    bool RemoveNodeHelper::checkIsSourceForClone(KisNodeSP src, const QList<KisNodeSP> &nodes) {
+    bool RemoveNodeHelper::checkIsSourceForClone(KisNodeSP src, const KisNodeList &nodes) {
         foreach (KisNodeSP node, nodes) {
             if (node == src) continue;
 
@@ -447,7 +447,7 @@ namespace KisLayerUtils {
         CleanUpNodes(MergeDownInfoBaseSP info, KisNodeSP putAfter)
             : m_info(info), m_putAfter(putAfter) {}
 
-        static void findPerfectParent(QList<KisNodeSP> nodesToDelete, KisNodeSP &putAfter, KisNodeSP &parent) {
+        static void findPerfectParent(KisNodeList nodesToDelete, KisNodeSP &putAfter, KisNodeSP &parent) {
             if (!putAfter) {
                 putAfter = nodesToDelete.last();
             }
@@ -461,7 +461,7 @@ namespace KisLayerUtils {
         }
 
         void populateChildCommands() {
-            QList<KisNodeSP> nodesToDelete = m_info->allSrcNodes();
+            KisNodeList nodesToDelete = m_info->allSrcNodes();
 
             KisNodeSP parent;
             findPerfectParent(nodesToDelete, m_putAfter, parent);
@@ -478,14 +478,16 @@ namespace KisLayerUtils {
                                                        true, false));
                 addCommand(new KisImageChangeLayersCommand(m_info->image, oldRoot, newRoot));
 
-            } else {
+            }
+            else {
                 if (parent == m_putAfter->parent()) {
                     addCommand(new KisImageLayerAddCommand(m_info->image,
                                                            m_info->dstNode,
                                                            parent,
                                                            m_putAfter,
                                                            true, false));
-                } else {
+                }
+                else {
                     addCommand(new KisImageLayerAddCommand(m_info->image,
                                                            m_info->dstNode,
                                                            parent,
@@ -677,9 +679,9 @@ namespace KisLayerUtils {
         applicator.end();
     }
 
-    bool checkIsChildOf(KisNodeSP node, const QList<KisNodeSP> &parents)
+    bool checkIsChildOf(KisNodeSP node, const KisNodeList &parents)
     {
-        QList<KisNodeSP> nodeParents;
+        KisNodeList nodeParents;
 
         KisNodeSP parent = node->parent();
         while (parent) {
@@ -696,9 +698,38 @@ namespace KisLayerUtils {
         return false;
     }
 
-    void filterMergableNodes(QList<KisNodeSP> &nodes, bool allowMasks)
+    bool checkIsCloneOf(KisNodeSP node, const KisNodeList &nodes)
     {
-        QList<KisNodeSP>::iterator it = nodes.begin();
+        bool result = false;
+
+        KisCloneLayer *clone = dynamic_cast<KisCloneLayer*>(node.data());
+        if (clone) {
+            KisNodeSP cloneSource = KisNodeSP(clone->copyFrom());
+
+            Q_FOREACH(KisNodeSP subtree, nodes) {
+                result =
+                    recursiveFindNode(subtree,
+                                      [cloneSource](KisNodeSP node) -> bool
+                                      {
+                                          return node == cloneSource;
+                                      });
+
+                if (!result) {
+                    result = checkIsCloneOf(cloneSource, nodes);
+                }
+
+                if (result) {
+                    break;
+                }
+            }
+        }
+
+        return result;
+    }
+
+    void filterMergableNodes(KisNodeList &nodes, bool allowMasks)
+    {
+        KisNodeList::iterator it = nodes.begin();
 
         while (it != nodes.end()) {
             if ((!allowMasks && !dynamic_cast<KisLayer*>(it->data())) ||
@@ -712,9 +743,9 @@ namespace KisLayerUtils {
         }
     }
 
-    void sortMergableNodes(KisNodeSP root, QList<KisNodeSP> &inputNodes, QList<KisNodeSP> &outputNodes)
+    void sortMergableNodes(KisNodeSP root, KisNodeList &inputNodes, KisNodeList &outputNodes)
     {
-        QList<KisNodeSP>::iterator it = std::find(inputNodes.begin(), inputNodes.end(), root);
+        KisNodeList::iterator it = std::find(inputNodes.begin(), inputNodes.end(), root);
 
         if (it != inputNodes.end()) {
             outputNodes << *it;
@@ -744,6 +775,29 @@ namespace KisLayerUtils {
         return result;
     }
 
+    KisNodeList sortAndFilterMergableInternalNodes(KisNodeList nodes, bool allowMasks)
+    {
+        KIS_ASSERT_RECOVER(!nodes.isEmpty()) { return nodes; }
+
+        KisNodeSP root;
+        Q_FOREACH(KisNodeSP node, nodes) {
+            KisNodeSP localRoot = node;
+            while (localRoot->parent()) {
+                localRoot = localRoot->parent();
+            }
+
+            if (!root) {
+                root = localRoot;
+            }
+            KIS_ASSERT_RECOVER(root == localRoot) { return nodes; }
+        }
+
+        KisNodeList result;
+        sortMergableNodes(root, nodes, result);
+        filterMergableNodes(result, allowMasks);
+        return result;
+    }
+
     void addCopyOfNameTag(KisNodeSP node)
     {
         const QString prefix = i18n("Copy of");
@@ -771,7 +825,8 @@ namespace KisLayerUtils {
         return nodes;
     }
 
-    KisNodeList filterInvisibleNodes(const KisNodeList &nodes, KisNodeList *invisibleNodes, KisNodeSP *putAfter) {
+    KisNodeList filterInvisibleNodes(const KisNodeList &nodes, KisNodeList *invisibleNodes, KisNodeSP *putAfter)
+    {
         KIS_ASSERT_RECOVER(invisibleNodes) { return nodes; }
         KIS_ASSERT_RECOVER(putAfter) { return nodes; }
 
@@ -798,11 +853,11 @@ namespace KisLayerUtils {
         return visibleNodes;
     }
 
-    void mergeMultipleLayersImpl(KisImageSP image, QList<KisNodeSP> mergedNodes, KisNodeSP putAfter, bool flattenSingleLayer, const KUndo2MagicString &actionName)
+    void mergeMultipleLayersImpl(KisImageSP image, KisNodeList mergedNodes, KisNodeSP putAfter, bool flattenSingleLayer, const KUndo2MagicString &actionName)
     {
         filterMergableNodes(mergedNodes);
         {
-            QList<KisNodeSP> tempNodes;
+            KisNodeList tempNodes;
             qSwap(mergedNodes, tempNodes);
             sortMergableNodes(image->root(), tempNodes, mergedNodes);
         }
@@ -864,7 +919,7 @@ namespace KisLayerUtils {
 
     }
 
-    void mergeMultipleLayers(KisImageSP image, QList<KisNodeSP> mergedNodes, KisNodeSP putAfter)
+    void mergeMultipleLayers(KisImageSP image, KisNodeList mergedNodes, KisNodeSP putAfter)
     {
         mergeMultipleLayersImpl(image, mergedNodes, putAfter, false, kundo2_i18n("Merge Selected Nodes"));
     }
@@ -920,12 +975,12 @@ namespace KisLayerUtils {
         MergeDownInfoBaseSP m_info;
     };
 
-    bool tryMergeSelectionMasks(KisImageSP image, QList<KisNodeSP> mergedNodes, KisNodeSP putAfter)
+    bool tryMergeSelectionMasks(KisImageSP image, KisNodeList mergedNodes, KisNodeSP putAfter)
     {
         QList<KisSelectionMaskSP> selectionMasks;
 
-        QList<KisNodeSP>::iterator it = mergedNodes.begin();
-        QList<KisNodeSP>::iterator end = mergedNodes.end();
+        KisNodeList::iterator it = mergedNodes.begin();
+        KisNodeList::iterator end = mergedNodes.end();
         while (it != end) {
             KisSelectionMaskSP mask = dynamic_cast<KisSelectionMask*>(it->data());
             if (!mask) {
@@ -967,7 +1022,7 @@ namespace KisLayerUtils {
         if (!layer->childCount() && !layer->layerStyle())
             return;
 
-        QList<KisNodeSP> mergedNodes;
+        KisNodeList mergedNodes;
         mergedNodes << layer;
 
         mergeMultipleLayersImpl(image, mergedNodes, layer, true, kundo2_i18n("Flatten Layer"));
@@ -975,7 +1030,7 @@ namespace KisLayerUtils {
 
     void flattenImage(KisImageSP image)
     {
-        QList<KisNodeSP> mergedNodes;
+        KisNodeList mergedNodes;
         mergedNodes << image->root();
 
         mergeMultipleLayersImpl(image, mergedNodes, 0, true, kundo2_i18n("Flatten Image"));
@@ -1007,4 +1062,22 @@ namespace KisLayerUtils {
             node = node->nextSibling();
         }
     }
+
+    KisNodeSP recursiveFindNode(KisNodeSP node, std::function<bool(KisNodeSP)> func)
+    {
+        if (func(node)) {
+            return node;
+        }
+
+        node = node->firstChild();
+        while (node) {
+            KisNodeSP resultNode = recursiveFindNode(node, func);
+            if (resultNode) {
+                return resultNode;
+            }
+            node = node->nextSibling();
+        }
+
+        return 0;
+    }
 }
