@@ -31,6 +31,8 @@ class QPainter;
 #include <QVector>
 #include "kritaimage_export.h"
 #include "kis_types.h"
+#include <functional>
+
 
 namespace KritaUtils
 {
@@ -93,6 +95,17 @@ namespace KritaUtils
         }
     }
 
+
+    template <class C>
+        void filterContainer(C &container, std::function<bool(typename C::value_type)> keepIf) {
+
+            auto newEnd = std::remove_if(container.begin(), container.end(), std::unary_negate<decltype(keepIf)>(keepIf));
+            while (newEnd != container.end()) {
+               newEnd = container.erase(newEnd);
+            }
+    }
+
+
     /**
      * When drawing a rect Qt uses quite a weird algorithm. It
      * draws 4 lines:
