@@ -47,7 +47,7 @@ QString KisMimeDatabase::mimeTypeForFile(const QString &file)
         debugPlugin << "mimeTypeForFile(). QMimeDatabase returned" << mime.name() << "for" << file;
         return mime.name();
     }
-    return QString();
+    return "";
 }
 
 QString KisMimeDatabase::mimeTypeForSuffix(const QString &suffix)
@@ -72,9 +72,7 @@ QString KisMimeDatabase::mimeTypeForSuffix(const QString &suffix)
         debugPlugin << "mimeTypeForSuffix(). QMimeDatabase returned" << mime.name() << "for" << s;
         return mime.name();
     }
-
-
-    return QString();
+    return "";
 }
 
 QString KisMimeDatabase::mimeTypeForData(const QByteArray ba)
@@ -99,11 +97,11 @@ QString KisMimeDatabase::descriptionForMimeType(const QString &mimeType)
     QMimeDatabase db;
     QMimeType mime = db.mimeTypeForName(mimeType);
     if (mime.name() != "application/octet-stream") {
-        debugPlugin << "descriptionForMimeType. QMimeDatabase returned" << mime.comment() << "for" << mimeType;
+        debugPlugin  << "descriptionForMimeType. QMimeDatabase returned" << mime.comment() << "for" << mimeType;
         return mime.comment();
     }
 
-    return QString();
+    return mimeType;
 }
 
 QStringList KisMimeDatabase::suffixesForMimeType(const QString &mimeType)
@@ -129,8 +127,7 @@ QStringList KisMimeDatabase::suffixesForMimeType(const QString &mimeType)
         debugPlugin << "suffixesForMimeType. QMimeDatabase returned" << suffixes;
         return suffixes;
     }
-
-    return QStringList(".kra");
+    return QStringList();
 }
 
 QString KisMimeDatabase::iconNameForMimeType(const QString &mimeType)
@@ -151,54 +148,111 @@ void KisMimeDatabase::fillMimeData()
 
         mimeType.mimeType = "image/x-gimp-brush";
         mimeType.description = i18nc("description of a file type", "Gimp Brush");
-        mimeType.suffixes << "*.gbr,*vbr";
+        mimeType.suffixes = QStringList() << "*.gbr" << "*.vbr";
         s_mimeDatabase << mimeType;
 
-        mimeType.mimeType = "image/x-gimp-brush";
+        mimeType.mimeType = "image/x-gimp-brush-animated";
         mimeType.description = i18nc("description of a file type", "Gimp Image Hose Brush");
-        mimeType.suffixes << "*.gih";
+        mimeType.suffixes = QStringList() << "*.gih";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "image/x-adobe-brushlibrary";
+        mimeType.description = i18nc("description of a file type", "Adobe Brush Library");
+        mimeType.suffixes = QStringList() << "*.abr";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-krita-paintoppreset";
         mimeType.description = i18nc("description of a file type", "Krita Brush Preset");
-        mimeType.suffixes << "*.kpp";
+        mimeType.suffixes = QStringList() << "*.kpp";
         s_mimeDatabase << mimeType;
 
-        mimeType.mimeType = "applicat/x-krita-assistant";
+        mimeType.mimeType = "application/x-krita-assistant";
         mimeType.description = i18nc("description of a file type", "Krita Assistant");
-        mimeType.suffixes << "*.paintingassistant";
+        mimeType.suffixes = QStringList() << "*.paintingassistant";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/x-r16";
         mimeType.description = i18nc("description of a file type", "R16 Heightmap");
-        mimeType.suffixes << "*.r16";
+        mimeType.suffixes = QStringList() <<  "*.r16";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/x-r8";
         mimeType.description = i18nc("description of a file type", "R8 Heightmap");
-        mimeType.suffixes << "*.r8";
+        mimeType.suffixes = QStringList() << "*.r8";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "application/x-spriter";
         mimeType.description = i18nc("description of a file type", "Spriter SCML");
-        mimeType.suffixes << "*.scml";
-        s_mimeDatabase << mimeType;
-
-        mimeType.mimeType = "";
-        mimeType.description = i18nc("description of a file type", "");
-        mimeType.suffixes << "*.";
+        mimeType.suffixes = QStringList() << "*.scml";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/x-svm";
         mimeType.description = i18nc("description of a file type", "Starview Metafile");
-        mimeType.suffixes << "*.svm";
+        mimeType.suffixes = QStringList() << "*.svm";
         s_mimeDatabase << mimeType;
 
         mimeType.mimeType = "image/openraster";
         mimeType.description = i18nc("description of a file type", "OpenRaster Image");
-        mimeType.suffixes << "*.ora";
+        mimeType.suffixes = QStringList() << "*.ora";
         s_mimeDatabase << mimeType;
 
+        mimeType.mimeType = "application/x-photoshop-style-library";
+        mimeType.description = i18nc("description of a file type", "Photoshop Layer Style Library");
+        mimeType.suffixes = QStringList() << "*.asl";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "application/x-gimp-color-palette";
+        mimeType.description = i18nc("description of a file type", "Gimp Color Palette");
+        mimeType.suffixes = QStringList() << "*.gpl" << "*.pal" << "*.act" << "*.aco" << "*.colors";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "application/x-opencolorio-configuration";
+        mimeType.description = i18nc("description of a file type", "OpenColorIO Configuration");
+        mimeType.suffixes = QStringList() << "*.ocio";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "application/x-krita-recorded-macro";
+        mimeType.description = i18nc("description of a file type", "Krita Recorded Action");
+        mimeType.suffixes = QStringList() << "*.krarec";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "application/x-gimp-gradient";
+        mimeType.description = i18nc("description of a file type", "GIMP Gradients");
+        mimeType.suffixes = QStringList() << "*.ggr";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "application/x-gimp-pattern";
+        mimeType.description = i18nc("description of a file type", "GIMP Patterns");
+        mimeType.suffixes = QStringList() << "*.pat";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "application/x-karbon-gradient";
+        mimeType.description = i18nc("description of a file type", "Karbon Gradients");
+        mimeType.suffixes = QStringList() << "*.kgr";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "application/x-krita-bundle";
+        mimeType.description = i18nc("description of a file type", "Krita Resource Bundle");
+        mimeType.suffixes = QStringList() << "*.bundle";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "application/x-krita-workspace";
+        mimeType.description = i18nc("description of a file type", "Krita Workspace");
+        mimeType.suffixes = QStringList() << "*.kts";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "image/x-krita-raw";
+        mimeType.description = i18nc("description of a file type", "Camera Raw Files");
+        mimeType.suffixes = QStringList() << "*.nef" << "*.cr2" << "*.sr2" << "*.crw" << "*.pef" << "*.x3f" << "*.kdc" << "*.mrw" << "*.arw" << "*.k25" << "*.dcr" << "*.orf" << "*.raw" << "*.raw" << "*.raf" << "*.srf" << "*.dng";
+        s_mimeDatabase << mimeType;
+
+        mimeType.mimeType = "application/x-extension-exr";
+        mimeType.description = i18nc("description of a file type", "OpenEXR (Extended)");
+        mimeType.suffixes = QStringList() << "*.exr";
+        s_mimeDatabase << mimeType;
+
+
+
         debugPlugin << "Filled mimedatabase with" << s_mimeDatabase.count() << "special mimetypes";
     }
 }
