@@ -345,7 +345,10 @@ KisMainWindow::KisMainWindow()
         QDockWidget *dw = createDockWidget(factory);
         dockwidgetActions[dw->toggleViewAction()->text()] = dw->toggleViewAction();
     }
-    dockwidgetActions[d->toolOptionsDocker->toggleViewAction()->text()] = d->toolOptionsDocker->toggleViewAction();
+
+    if (d->toolOptionsDocker) {
+        dockwidgetActions[d->toolOptionsDocker->toggleViewAction()->text()] = d->toolOptionsDocker->toggleViewAction();
+    }
 
     Q_FOREACH (QString title, dockwidgetActions.keys()) {
         d->dockWidgetMenu->addAction(dockwidgetActions[title]);
@@ -449,17 +452,9 @@ KisMainWindow::KisMainWindow()
 
     // If we have customized the toolbars, load that first
     setLocalXMLFile(KoResourcePaths::locateLocal("data", "krita.xmlgui"));
-
-    QString doc;
-    QStringList allFiles = KoResourcePaths::findAllResources("data", "krita.xmlgui");
-    // We need at least one krita.xmlgui file!
-    if (allFiles.size() == 0) {
-        m_errorMessage = i18n("Krita cannot find the configuration file! Krita will quit now.");
-        m_dieOnError = true;
-        QTimer::singleShot(0, this, SLOT(showErrorAndDie()));
-        return;
-    }
-    setXMLFile(findMostRecentXMLFile(allFiles, doc));
+    QFile doc(":/kxmlgui5/krita.xmlgui");
+    doc.open(QFile::ReadOnly);
+    setXML(doc.readAll());
 
     guiFactory()->addClient(this);
 
@@ -797,9 +792,6 @@ QStringList KisMainWindow::showOpenFileDialog()
     dialog.setMimeTypeFilters(KisImportExportManager::mimeFilter(KIS_MIME_TYPE,
                                                                  KisImportExportManager::Import,
                                                                  KisDocument::extraNativeMimeTypes()));
-    QStringList filters = dialog.nameFilters();
-    filters << i18n("All files (*.*)");
-    dialog.setNameFilters(filters);
     dialog.setHideNameFilterDetailsOption();
     dialog.setCaption(isImporting() ? i18n("Import Images") : i18n("Open Images"));
 
